@@ -22,12 +22,13 @@
 	2014.02.12 V00.16 Changed Busy logic
 	2014.02.13 V00.17 Changed Busy logic
 	2014.02.14 V00.18 Changed Hole Punching packet format
+	2014.02.16 V00.19 Bug fixed for CallCheck
 */
 
 #include	"dsgwd_pi.h"
 #include	"version.h"
 #include	"node.h"
-#include	"holeP.h"
+#include	"holeP.h"	/* Hole Punching packet format */
 
 void	*node_adapter (void *arg);
 void	send_dsvt(void);
@@ -317,7 +318,7 @@ int main(int argc, const char **argv)
 	{
         	logfile = fopen (LOGFILE, "a");
         	now = time(NULL);
-        	fprintf (logfile, "%24.24s Must run on supper user\n");
+        	fprintf (logfile, "%24.24s Must run on supper user\n", ctime(&now));
         	fclose(logfile);
 		exit(-1);
 	}
@@ -342,6 +343,7 @@ int main(int argc, const char **argv)
 	KeepAliveCnt = 0;
 	NodeVendorID =  VendorID;
 	NodeProductID = ProductID;
+	CallCheck = FALSE;
 
 	config (argc, (char **)argv);
 
@@ -472,7 +474,7 @@ int main(int argc, const char **argv)
         udpAddr.sin_addr.s_addr = htonl(INADDR_ANY);
         bind(udpSocket, (struct sockaddr *)&udpAddr, sizeof(udpAddr));
 
-	loadCallCheckACL();
+	if (CallCheck) loadCallCheckACL();
 
         FD_ZERO(&Mask);
         FD_SET(dstSocket, &Mask);
@@ -556,7 +558,7 @@ int main(int argc, const char **argv)
 						{
 							logfile = fopen	(LOGFILE, "a");
 							now = time(NULL);
-							fprintf (logfile, "24.24s Receive Ack\n", ctime(&now));
+							fprintf (logfile, "%24.24s Receive Ack\n", ctime(&now));
 							fclose (logfile);
 							dstPort = reqConMsg.ackConnect.port;
 							dstIP = reqConMsg.ackConnect.ip;
@@ -584,7 +586,8 @@ int main(int argc, const char **argv)
                         		{
         					logfile = fopen (LOGFILE, "a");
         					now = time(NULL);
-                                		fprintf (logfile, "%24.24s Req %2.2x %2.2x %8.8s %s %d\n", ctime(&now),
+                                		fprintf (logfile, "%24.24s Req %2.2x %2.2x %8.8s %s %d\n", 
+							ctime(&now),
 							reqConMsg.reqType,
 							reqConMsg.reqConnect.protocol, 
 							reqConMsg.reqConnect.YourCall, 
