@@ -29,6 +29,15 @@
 #define INET            2
 #define JitterBufferSize        21
 
+struct header {
+        unsigned char   flags[3];
+        char            Rpt2Call[8];
+        char            Rpt1Call[8];
+        char            YourCall[8];
+        char            MyCall[8];
+        char            MyCall2[4];
+        unsigned char   crc[2];
+};
 
 void    from_node(void);
 void    send_voice_queue(void);
@@ -36,7 +45,7 @@ void    send_header_queue(void);
 void    BeepSend (char callsign[], char flags);
 int     BitsCheck(char pattern1[], char pattern2[], int cnt);
 void    Ptt_Off(void);
-void    send_header_USB(char pkt[]);
+void    send_header_USB(struct header pkt);
 void    send_voice_USB (char pkt[], char seq);
 void    JitterBufferSend (void);
 void    JitterBufferSave (char VoicePacket[], unsigned char sequence);
@@ -167,16 +176,7 @@ struct packet{
 		unsigned char	seq;
 	} B_header;
 	union {
-                        struct
-                        {
-                                unsigned char   flags[3];
-                                char            Rpt2Call[8];
-                                char            Rpt1Call[8];
-                                char            YourCall[8];
-                                char            MyCall[8];
-                                char            Mycall2[4];
-                                unsigned char   crc[2];
-                        } header;
+                        struct	header header;
 			struct
 			{
 				char	voice[9];
