@@ -104,7 +104,7 @@ void	from_rig(void)
 					if (Packet_Seq > 20) Packet_Seq = 0;
 					headerRead = FALSE;
 					SendHeader = FALSE;
-					sprintf (msg,"CALLED FROM %8.8s",&rf_header.MyCall);
+					sprintf (msg,"CALLED FROM %8.8s", rf_header.MyCall);
 					if (SendToInet) BeepSend(rf_header.MyCall, respFlags);
 					COS_On = FALSE;
 					return;
